#<profile4xi profile = "10" />
# -------------------------------------------------------------------------------------------------
#<program4xi program = "_validate_family4xi.py">
#<abstract4xi abstract = "provides the function _validate_family4xi"/>
#<refer4xi reference = "connection.py"/>
#<state4xi status = "ACK4tagging; ACK4moduletesting; NACK4systemtesting; [Rel 7.21]"/>
#<note4xi note = "new in [Rel 7.21]"/>
# -------------------------------------------------------------------------------------------------

# -------------------------------------------------------------------------------------------------
# Public API
# -------------------------------------------------------------------------------------------------
#<interface4xi interface = " 
__all__ = ['_validate_family4xi']
#"
#/>


# -------------------------------------------------------------------------------------------------
# Standard Imports                          
# -------------------------------------------------------------------------------------------------
#<standardize4xi standard = "
import os
import sys
import threading                
import _thread
import _winapi   

import socket
import errno
import time
import tempfile
import itertools
#"
#/>

# -------------------------------------------------------------------------------------------------
# Multiprocessing Imports                          
# -------------------------------------------------------------------------------------------------
#<process4xi process = "
import _multiprocessing
from multiprocessing import connection
#"
#/>

# -------------------------------------------------------------------------------------------------
# DragonXi imports                              
# -------------------------------------------------------------------------------------------------
#<dragonize4xi dragonization = "
from print4xi import print4xi
from time4xi import time4xi
#"
#/>


# -------------------------------------------------------------------------------------------------
#<function4xi function = "_validate_family4xi" usage = "
#   connection.py
#       class Listener(object):
#           def __init__(self, address=None, family=None, backlog=1, authkey=None):
#               family = family or (address and address_type(address)) \
#                                or default_family
#               address = address or arbitrary_address(family)
#               
#               _validate_family(family)
#               if family == 'AF_PIPE':
#                   self._listener = PipeListener(address, backlog)
#               else:
#                   self._listener = SocketListener(address, family, backlog)
#
#"> 
#<state4xi status = "ACK4tagging; ACK4moduletesting; NACK4systemtesting; [Rel 7.21]"/>
# -------------------------------------------------------------------------------------------------
def _validate_family4xi(family):
    '''
    checks if the family is valid for the current environment
    '''
    
    # -----------------------------------------------------------------------------------------    
    # (Step 1/4) 
    # -----------------------------------------------------------------------------------------        
        
    class2print = "_validate_family4xi"
    method2print = "_validate_family4xi"

    
    message2print = "{(Step 1/4a)  started" + "; _validate_family4xi-started: " + str(_validate_family4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print) 
        
    message2print = "{(Step 1/4b) passed" + "; family-passed-to-_validate_family4xi: " + str(family) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
    # 
     
                
    # -----------------------------------------------------------------------------------------    
    # (Step 2/4) 
    # -----------------------------------------------------------------------------------------        
    if sys.platform != 'win32' and family == 'AF_PIPE':
        message2print = "{(Step 2/4a) warned" + "; family-warned-by-_validate_family4xi: " + str(family)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        # 
        
        message2print = "{(Step 2/4b) warned" + "; platform-warned-by-_validate_family4xi: " + str(sys.platform)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        # 
    
        raise ValueError('Family %s is not recognized by _validate_family4xi ' % family)
        
                
    # -----------------------------------------------------------------------------------------    
    # (Step 3/4) 
    # -----------------------------------------------------------------------------------------        
    if sys.platform == 'win32' and family == 'AF_UNIX':
        if not hasattr(socket, family):
            message2print = "{(Step 3/4a) warned" + "; family-warned-by-_validate_family4xi: " + str(family)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            # 
            
            message2print = "{(Step 3/4b) warned" + "; platform-warned-by-_validate_family4xi: " + str(sys.platform)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            # 
            
            message2print = "{(Step 3/4c) warned" + "; socket-warned-by-_validate_family4xi: " + str(socket)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            # 
        
            raise ValueError('Family %s is not recognized by _validate_family4xi ' % family)
        
        
    # -----------------------------------------------------------------------------------------    
    # (Step 4/4)
    # -----------------------------------------------------------------------------------------     
    message2print = "{(Step 4/4) returning" + "; _validate_family4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print) 
    #  
        
        
    return
    
#</function4xi>
#</program4xi>

# -------------------------------------------------------------------------------------------------
# Recorded History                             
# ------------------------------------------------------------------------------------------------- 
#<record4xi record = "
#   test_validate_family4xi.txt
#   sense-test-_validate_family4xi.xml
#   reason-test-_validate_family4xi.xml
#   ace-test-_validate_family4xi.xml
#"
#>


# -------------------------------------------------------------------------------------------------
# Legal Notice                             
# ------------------------------------------------------------------------------------------------- 
#<protect4xi protection = "copyright"
#   owner = "Small & Smart"
#   rights = "All rights reserved"
#   state = "California"
#   country = "United States of America"
#   references = "Legal notice at www.dragonxi.com; www.yourdragonxi.com; www.yourdragonxi.org; www.dragon2xi.com/; www.dragon4xi.com/; www.dragon8xi.com/ " 
#   codes = "Codes established in California and applicable to corporations in California"
#   compliance = "The California Law"
#   court = "Supreme Court of California, 350 McAllister Street, San Francisco, CA 94102-4783"
#/>
 

#<end4xi end = "
# -------------------------------------------------------------------------------------------------
# end of _validate_family4xi.py                             
# ------------------------------------------------------------------------------------------------- 
#"
#/>


